# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_issuer_issue_with_role_request import PkiIssuerIssueWithRoleRequest

class TestPkiIssuerIssueWithRoleRequest(unittest.TestCase):
    """PkiIssuerIssueWithRoleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiIssuerIssueWithRoleRequest:
        """Test PkiIssuerIssueWithRoleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiIssuerIssueWithRoleRequest`
        """
        model = PkiIssuerIssueWithRoleRequest()
        if include_optional:
            return PkiIssuerIssueWithRoleRequest(
                alt_names = '',
                common_name = '',
                exclude_cn_from_sans = True,
                format = 'pem',
                ip_sans = [
                    ''
                    ],
                not_after = '',
                other_sans = [
                    ''
                    ],
                private_key_format = 'der',
                remove_roots_from_chain = True,
                serial_number = '',
                ttl = '',
                uri_sans = [
                    ''
                    ],
                user_ids = [
                    ''
                    ]
            )
        else:
            return PkiIssuerIssueWithRoleRequest(
        )
        """

    def testPkiIssuerIssueWithRoleRequest(self):
        """Test PkiIssuerIssueWithRoleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LeaderStatusResponse(BaseModel):
    """
    LeaderStatusResponse
    """ # noqa: E501
    active_time: Optional[datetime] = None
    ha_enabled: Optional[StrictBool] = None
    is_self: Optional[StrictBool] = None
    last_wal: Optional[StrictInt] = None
    leader_address: Optional[StrictStr] = None
    leader_cluster_address: Optional[StrictStr] = None
    performance_standby: Optional[StrictBool] = None
    performance_standby_last_remote_wal: Optional[StrictInt] = None
    raft_applied_index: Optional[StrictInt] = None
    raft_committed_index: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["active_time", "ha_enabled", "is_self", "last_wal", "leader_address", "leader_cluster_address", "performance_standby", "performance_standby_last_remote_wal", "raft_applied_index", "raft_committed_index"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LeaderStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LeaderStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "active_time": obj.get("active_time"),
            "ha_enabled": obj.get("ha_enabled"),
            "is_self": obj.get("is_self"),
            "last_wal": obj.get("last_wal"),
            "leader_address": obj.get("leader_address"),
            "leader_cluster_address": obj.get("leader_cluster_address"),
            "performance_standby": obj.get("performance_standby"),
            "performance_standby_last_remote_wal": obj.get("performance_standby_last_remote_wal"),
            "raft_applied_index": obj.get("raft_applied_index"),
            "raft_committed_index": obj.get("raft_committed_index")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TotpCreateKeyRequest(BaseModel):
    """
    TotpCreateKeyRequest
    """ # noqa: E501
    account_name: Optional[StrictStr] = Field(default=None, description="The name of the account associated with the key. Required if generate is true.")
    algorithm: Optional[StrictStr] = Field(default='SHA1', description="The hashing algorithm used to generate the TOTP token. Options include SHA1, SHA256 and SHA512.")
    digits: Optional[StrictInt] = Field(default=6, description="The number of digits in the generated TOTP token. This value can either be 6 or 8.")
    exported: Optional[StrictBool] = Field(default=True, description="Determines if a QR code and url are returned upon generating a key. Only used if generate is true.")
    generate: Optional[StrictBool] = Field(default=False, description="Determines if a key should be generated by Vault or if a key is being passed from another service.")
    issuer: Optional[StrictStr] = Field(default=None, description="The name of the key's issuing organization. Required if generate is true.")
    key: Optional[StrictStr] = Field(default=None, description="The shared master key used to generate a TOTP token. Only used if generate is false.")
    key_size: Optional[StrictInt] = Field(default=20, description="Determines the size in bytes of the generated key. Only used if generate is true.")
    period: Optional[StrictStr] = Field(default='30', description="The length of time used to generate a counter for the TOTP token calculation.")
    qr_size: Optional[StrictInt] = Field(default=200, description="The pixel size of the generated square QR code. Only used if generate is true and exported is true. If this value is 0, a QR code will not be returned.")
    skew: Optional[StrictInt] = Field(default=1, description="The number of delay periods that are allowed when validating a TOTP token. This value can either be 0 or 1. Only used if generate is true.")
    url: Optional[StrictStr] = Field(default=None, description="A TOTP url string containing all of the parameters for key setup. Only used if generate is false.")
    __properties: ClassVar[List[str]] = ["account_name", "algorithm", "digits", "exported", "generate", "issuer", "key", "key_size", "period", "qr_size", "skew", "url"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TotpCreateKeyRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TotpCreateKeyRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "account_name": obj.get("account_name"),
            "algorithm": obj.get("algorithm") if obj.get("algorithm") is not None else 'SHA1',
            "digits": obj.get("digits") if obj.get("digits") is not None else 6,
            "exported": obj.get("exported") if obj.get("exported") is not None else True,
            "generate": obj.get("generate") if obj.get("generate") is not None else False,
            "issuer": obj.get("issuer"),
            "key": obj.get("key"),
            "key_size": obj.get("key_size") if obj.get("key_size") is not None else 20,
            "period": obj.get("period") if obj.get("period") is not None else '30',
            "qr_size": obj.get("qr_size") if obj.get("qr_size") is not None else 200,
            "skew": obj.get("skew") if obj.get("skew") is not None else 1,
            "url": obj.get("url")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiRevokeIssuerResponse(BaseModel):
    """
    PkiRevokeIssuerResponse
    """ # noqa: E501
    ca_chain: Optional[List[StrictStr]] = Field(default=None, description="Certificate Authority Chain")
    certificate: Optional[StrictStr] = Field(default=None, description="Certificate")
    crl_distribution_points: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the CRL Distribution Points field")
    issuer_id: Optional[StrictStr] = Field(default=None, description="ID of the issuer")
    issuer_name: Optional[StrictStr] = Field(default=None, description="Name of the issuer")
    issuing_certificates: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the Issuing Certificate field")
    key_id: Optional[StrictStr] = Field(default=None, description="ID of the Key")
    leaf_not_after_behavior: Optional[StrictStr] = None
    manual_chain: Optional[List[StrictStr]] = Field(default=None, description="Manual Chain")
    ocsp_servers: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the OCSP Servers field")
    revocation_signature_algorithm: Optional[StrictStr] = Field(default=None, description="Which signature algorithm to use when building CRLs")
    revocation_time: Optional[StrictInt] = Field(default=None, description="Time of revocation")
    revocation_time_rfc3339: Optional[datetime] = Field(default=None, description="RFC formatted time of revocation")
    revoked: Optional[StrictBool] = Field(default=None, description="Whether the issuer was revoked")
    usage: Optional[StrictStr] = Field(default=None, description="Allowed usage")
    __properties: ClassVar[List[str]] = ["ca_chain", "certificate", "crl_distribution_points", "issuer_id", "issuer_name", "issuing_certificates", "key_id", "leaf_not_after_behavior", "manual_chain", "ocsp_servers", "revocation_signature_algorithm", "revocation_time", "revocation_time_rfc3339", "revoked", "usage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiRevokeIssuerResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiRevokeIssuerResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ca_chain": obj.get("ca_chain"),
            "certificate": obj.get("certificate"),
            "crl_distribution_points": obj.get("crl_distribution_points"),
            "issuer_id": obj.get("issuer_id"),
            "issuer_name": obj.get("issuer_name"),
            "issuing_certificates": obj.get("issuing_certificates"),
            "key_id": obj.get("key_id"),
            "leaf_not_after_behavior": obj.get("leaf_not_after_behavior"),
            "manual_chain": obj.get("manual_chain"),
            "ocsp_servers": obj.get("ocsp_servers"),
            "revocation_signature_algorithm": obj.get("revocation_signature_algorithm"),
            "revocation_time": obj.get("revocation_time"),
            "revocation_time_rfc3339": obj.get("revocation_time_rfc3339"),
            "revoked": obj.get("revoked"),
            "usage": obj.get("usage")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiConfigureAcmeRequest(BaseModel):
    """
    PkiConfigureAcmeRequest
    """ # noqa: E501
    allow_role_ext_key_usage: Optional[StrictBool] = Field(default=False, description="whether the ExtKeyUsage field from a role is used, defaults to false meaning that certificate will be signed with ServerAuth.")
    allowed_issuers: Optional[List[StrictStr]] = Field(default=None, description="which issuers are allowed for use with ACME; by default, this will only be the primary (default) issuer")
    allowed_roles: Optional[List[StrictStr]] = Field(default=None, description="which roles are allowed for use with ACME; by default via '*', these will be all roles including sign-verbatim; when concrete role names are specified, any default_directory_policy role must be included to allow usage of the default acme directories under /pki/acme/directory and /pki/issuer/:issuer_id/acme/directory.")
    default_directory_policy: Optional[StrictStr] = Field(default='sign-verbatim', description="the policy to be used for non-role-qualified ACME requests; by default ACME issuance will be otherwise unrestricted, equivalent to the sign-verbatim endpoint; one may also specify a role to use as this policy, as \"role:<role_name>\", the specified role must be allowed by allowed_roles")
    dns_resolver: Optional[StrictStr] = Field(default='', description="DNS resolver to use for domain resolution on this mount. Defaults to using the default system resolver. Must be in the format <host>:<port>, with both parts mandatory.")
    eab_policy: Optional[StrictStr] = Field(default='always-required', description="Specify the policy to use for external account binding behaviour, 'not-required', 'new-account-required' or 'always-required'")
    enabled: Optional[StrictBool] = Field(default=False, description="whether ACME is enabled, defaults to false meaning that clusters will by default not get ACME support")
    __properties: ClassVar[List[str]] = ["allow_role_ext_key_usage", "allowed_issuers", "allowed_roles", "default_directory_policy", "dns_resolver", "eab_policy", "enabled"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiConfigureAcmeRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiConfigureAcmeRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allow_role_ext_key_usage": obj.get("allow_role_ext_key_usage") if obj.get("allow_role_ext_key_usage") is not None else False,
            "allowed_issuers": obj.get("allowed_issuers"),
            "allowed_roles": obj.get("allowed_roles"),
            "default_directory_policy": obj.get("default_directory_policy") if obj.get("default_directory_policy") is not None else 'sign-verbatim',
            "dns_resolver": obj.get("dns_resolver") if obj.get("dns_resolver") is not None else '',
            "eab_policy": obj.get("eab_policy") if obj.get("eab_policy") is not None else 'always-required',
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ConsulWriteRoleRequest(BaseModel):
    """
    ConsulWriteRoleRequest
    """ # noqa: E501
    consul_namespace: Optional[StrictStr] = Field(default=None, description="Indicates which namespace that the token will be created within. Defaults to 'default'. Available in Consul 1.7 and above.")
    consul_policies: Optional[List[StrictStr]] = Field(default=None, description="List of policies to attach to the token. Either \"consul_policies\" or \"consul_roles\" are required for Consul 1.5 and above, or just \"consul_policies\" if using Consul 1.4.")
    consul_roles: Optional[List[StrictStr]] = Field(default=None, description="List of Consul roles to attach to the token. Either \"policies\" or \"consul_roles\" are required for Consul 1.5 and above.")
    lease: Optional[StrictStr] = Field(default=None, description="Use \"ttl\" instead.")
    local: Optional[StrictBool] = Field(default=None, description="Indicates that the token should not be replicated globally and instead be local to the current datacenter. Available in Consul 1.4 and above.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="Max TTL for the Consul token created from the role.")
    node_identities: Optional[List[StrictStr]] = Field(default=None, description="List of Node Identities to attach to the token. Available in Consul 1.8.1 or above.")
    partition: Optional[StrictStr] = Field(default=None, description="Indicates which admin partition that the token will be created within. Defaults to 'default'. Available in Consul 1.11 and above.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Use \"consul_policies\" instead.")
    policy: Optional[StrictStr] = Field(default=None, description="Policy document, base64 encoded. Required for 'client' tokens. Required for Consul pre-1.4.")
    service_identities: Optional[List[StrictStr]] = Field(default=None, description="List of Service Identities to attach to the token, separated by semicolons. Available in Consul 1.5 or above.")
    token_type: Optional[StrictStr] = Field(default='client', description="Which type of token to create: 'client' or 'management'. If a 'management' token, the \"policy\", \"policies\", and \"consul_roles\" parameters are not required. Defaults to 'client'.")
    ttl: Optional[StrictStr] = Field(default=None, description="TTL for the Consul token created from the role.")
    __properties: ClassVar[List[str]] = ["consul_namespace", "consul_policies", "consul_roles", "lease", "local", "max_ttl", "node_identities", "partition", "policies", "policy", "service_identities", "token_type", "ttl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ConsulWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ConsulWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "consul_namespace": obj.get("consul_namespace"),
            "consul_policies": obj.get("consul_policies"),
            "consul_roles": obj.get("consul_roles"),
            "lease": obj.get("lease"),
            "local": obj.get("local"),
            "max_ttl": obj.get("max_ttl"),
            "node_identities": obj.get("node_identities"),
            "partition": obj.get("partition"),
            "policies": obj.get("policies"),
            "policy": obj.get("policy"),
            "service_identities": obj.get("service_identities"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'client',
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ahvac.models.ali_cloud_configure_request import AliCloudConfigureRequest
from ahvac.models.ali_cloud_login_request import AliCloudLoginRequest
from ahvac.models.ali_cloud_write_auth_role_request import AliCloudWriteAuthRoleRequest
from ahvac.models.ali_cloud_write_role_request import AliCloudWriteRoleRequest
from ahvac.models.alias_create_request import AliasCreateRequest
from ahvac.models.alias_update_by_id_request import AliasUpdateByIdRequest
from ahvac.models.app_role_destroy_secret_id_by_accessor_request import AppRoleDestroySecretIdByAccessorRequest
from ahvac.models.app_role_destroy_secret_id_request import AppRoleDestroySecretIdRequest
from ahvac.models.app_role_login_request import AppRoleLoginRequest
from ahvac.models.app_role_login_response import AppRoleLoginResponse
from ahvac.models.app_role_look_up_secret_id_by_accessor_request import AppRoleLookUpSecretIdByAccessorRequest
from ahvac.models.app_role_look_up_secret_id_by_accessor_response import AppRoleLookUpSecretIdByAccessorResponse
from ahvac.models.app_role_look_up_secret_id_request import AppRoleLookUpSecretIdRequest
from ahvac.models.app_role_look_up_secret_id_response import AppRoleLookUpSecretIdResponse
from ahvac.models.app_role_read_bind_secret_id_response import AppRoleReadBindSecretIdResponse
from ahvac.models.app_role_read_bound_cidr_list_response import AppRoleReadBoundCidrListResponse
from ahvac.models.app_role_read_local_secret_ids_response import AppRoleReadLocalSecretIdsResponse
from ahvac.models.app_role_read_period_response import AppRoleReadPeriodResponse
from ahvac.models.app_role_read_policies_response import AppRoleReadPoliciesResponse
from ahvac.models.app_role_read_role_id_response import AppRoleReadRoleIdResponse
from ahvac.models.app_role_read_role_response import AppRoleReadRoleResponse
from ahvac.models.app_role_read_secret_id_bound_cidrs_response import AppRoleReadSecretIdBoundCidrsResponse
from ahvac.models.app_role_read_secret_id_num_uses_response import AppRoleReadSecretIdNumUsesResponse
from ahvac.models.app_role_read_secret_id_ttl_response import AppRoleReadSecretIdTtlResponse
from ahvac.models.app_role_read_token_bound_cidrs_response import AppRoleReadTokenBoundCidrsResponse
from ahvac.models.app_role_read_token_max_ttl_response import AppRoleReadTokenMaxTtlResponse
from ahvac.models.app_role_read_token_num_uses_response import AppRoleReadTokenNumUsesResponse
from ahvac.models.app_role_read_token_ttl_response import AppRoleReadTokenTtlResponse
from ahvac.models.app_role_write_bind_secret_id_request import AppRoleWriteBindSecretIdRequest
from ahvac.models.app_role_write_bound_cidr_list_request import AppRoleWriteBoundCidrListRequest
from ahvac.models.app_role_write_custom_secret_id_request import AppRoleWriteCustomSecretIdRequest
from ahvac.models.app_role_write_custom_secret_id_response import AppRoleWriteCustomSecretIdResponse
from ahvac.models.app_role_write_period_request import AppRoleWritePeriodRequest
from ahvac.models.app_role_write_policies_request import AppRoleWritePoliciesRequest
from ahvac.models.app_role_write_role_id_request import AppRoleWriteRoleIdRequest
from ahvac.models.app_role_write_role_request import AppRoleWriteRoleRequest
from ahvac.models.app_role_write_secret_id_bound_cidrs_request import AppRoleWriteSecretIdBoundCidrsRequest
from ahvac.models.app_role_write_secret_id_num_uses_request import AppRoleWriteSecretIdNumUsesRequest
from ahvac.models.app_role_write_secret_id_request import AppRoleWriteSecretIdRequest
from ahvac.models.app_role_write_secret_id_response import AppRoleWriteSecretIdResponse
from ahvac.models.app_role_write_secret_id_ttl_request import AppRoleWriteSecretIdTtlRequest
from ahvac.models.app_role_write_token_bound_cidrs_request import AppRoleWriteTokenBoundCidrsRequest
from ahvac.models.app_role_write_token_max_ttl_request import AppRoleWriteTokenMaxTtlRequest
from ahvac.models.app_role_write_token_num_uses_request import AppRoleWriteTokenNumUsesRequest
from ahvac.models.app_role_write_token_ttl_request import AppRoleWriteTokenTtlRequest
from ahvac.models.auditing_calculate_hash_request import AuditingCalculateHashRequest
from ahvac.models.auditing_calculate_hash_response import AuditingCalculateHashResponse
from ahvac.models.auditing_enable_device_request import AuditingEnableDeviceRequest
from ahvac.models.auditing_enable_request_header_request import AuditingEnableRequestHeaderRequest
from ahvac.models.auditing_list_request_headers_response import AuditingListRequestHeadersResponse
from ahvac.models.auth_enable_method_request import AuthEnableMethodRequest
from ahvac.models.auth_read_configuration_response import AuthReadConfigurationResponse
from ahvac.models.auth_read_tuning_information_response import AuthReadTuningInformationResponse
from ahvac.models.auth_tune_configuration_parameters_request import AuthTuneConfigurationParametersRequest
from ahvac.models.aws_configure_certificate_request import AwsConfigureCertificateRequest
from ahvac.models.aws_configure_client_request import AwsConfigureClientRequest
from ahvac.models.aws_configure_identity_access_list_tidy_operation_request import AwsConfigureIdentityAccessListTidyOperationRequest
from ahvac.models.aws_configure_identity_integration_request import AwsConfigureIdentityIntegrationRequest
from ahvac.models.aws_configure_identity_whitelist_tidy_operation_request import AwsConfigureIdentityWhitelistTidyOperationRequest
from ahvac.models.aws_configure_lease_request import AwsConfigureLeaseRequest
from ahvac.models.aws_configure_role_tag_blacklist_tidy_operation_request import AwsConfigureRoleTagBlacklistTidyOperationRequest
from ahvac.models.aws_configure_role_tag_deny_list_tidy_operation_request import AwsConfigureRoleTagDenyListTidyOperationRequest
from ahvac.models.aws_configure_root_iam_credentials_request import AwsConfigureRootIamCredentialsRequest
from ahvac.models.aws_generate_credentials_with_parameters_request import AwsGenerateCredentialsWithParametersRequest
from ahvac.models.aws_generate_sts_credentials_with_parameters_request import AwsGenerateStsCredentialsWithParametersRequest
from ahvac.models.aws_login_request import AwsLoginRequest
from ahvac.models.aws_read_static_creds_name_response import AwsReadStaticCredsNameResponse
from ahvac.models.aws_read_static_roles_name_response import AwsReadStaticRolesNameResponse
from ahvac.models.aws_tidy_identity_access_list_request import AwsTidyIdentityAccessListRequest
from ahvac.models.aws_tidy_identity_whitelist_request import AwsTidyIdentityWhitelistRequest
from ahvac.models.aws_tidy_role_tag_blacklist_request import AwsTidyRoleTagBlacklistRequest
from ahvac.models.aws_tidy_role_tag_deny_list_request import AwsTidyRoleTagDenyListRequest
from ahvac.models.aws_write_auth_role_request import AwsWriteAuthRoleRequest
from ahvac.models.aws_write_role_request import AwsWriteRoleRequest
from ahvac.models.aws_write_role_tag_request import AwsWriteRoleTagRequest
from ahvac.models.aws_write_static_roles_name_request import AwsWriteStaticRolesNameRequest
from ahvac.models.aws_write_static_roles_name_response import AwsWriteStaticRolesNameResponse
from ahvac.models.aws_write_sts_role_request import AwsWriteStsRoleRequest
from ahvac.models.azure_configure_auth_request import AzureConfigureAuthRequest
from ahvac.models.azure_configure_request import AzureConfigureRequest
from ahvac.models.azure_login_request import AzureLoginRequest
from ahvac.models.azure_write_auth_role_request import AzureWriteAuthRoleRequest
from ahvac.models.azure_write_role_request import AzureWriteRoleRequest
from ahvac.models.centrify_configure_request import CentrifyConfigureRequest
from ahvac.models.centrify_login_request import CentrifyLoginRequest
from ahvac.models.cert_configure_request import CertConfigureRequest
from ahvac.models.cert_login_request import CertLoginRequest
from ahvac.models.cert_write_certificate_request import CertWriteCertificateRequest
from ahvac.models.cert_write_crl_request import CertWriteCrlRequest
from ahvac.models.cloud_foundry_configure_request import CloudFoundryConfigureRequest
from ahvac.models.cloud_foundry_login_request import CloudFoundryLoginRequest
from ahvac.models.cloud_foundry_write_role_request import CloudFoundryWriteRoleRequest
from ahvac.models.collect_host_information_response import CollectHostInformationResponse
from ahvac.models.consul_configure_access_request import ConsulConfigureAccessRequest
from ahvac.models.consul_write_role_request import ConsulWriteRoleRequest
from ahvac.models.cors_configure_request import CorsConfigureRequest
from ahvac.models.cors_read_configuration_response import CorsReadConfigurationResponse
from ahvac.models.database_configure_connection_request import DatabaseConfigureConnectionRequest
from ahvac.models.database_write_role_request import DatabaseWriteRoleRequest
from ahvac.models.database_write_static_role_request import DatabaseWriteStaticRoleRequest
from ahvac.models.decode_request import DecodeRequest
from ahvac.models.encryption_key_configure_rotation_request import EncryptionKeyConfigureRotationRequest
from ahvac.models.encryption_key_read_rotation_configuration_response import EncryptionKeyReadRotationConfigurationResponse
from ahvac.models.entity_batch_delete_request import EntityBatchDeleteRequest
from ahvac.models.entity_create_alias_request import EntityCreateAliasRequest
from ahvac.models.entity_create_request import EntityCreateRequest
from ahvac.models.entity_look_up_request import EntityLookUpRequest
from ahvac.models.entity_merge_request import EntityMergeRequest
from ahvac.models.entity_update_alias_by_id_request import EntityUpdateAliasByIdRequest
from ahvac.models.entity_update_by_id_request import EntityUpdateByIdRequest
from ahvac.models.entity_update_by_name_request import EntityUpdateByNameRequest
from ahvac.models.generate_hash_request import GenerateHashRequest
from ahvac.models.generate_hash_response import GenerateHashResponse
from ahvac.models.generate_hash_with_algorithm_request import GenerateHashWithAlgorithmRequest
from ahvac.models.generate_hash_with_algorithm_response import GenerateHashWithAlgorithmResponse
from ahvac.models.generate_random_request import GenerateRandomRequest
from ahvac.models.generate_random_response import GenerateRandomResponse
from ahvac.models.generate_random_with_bytes_request import GenerateRandomWithBytesRequest
from ahvac.models.generate_random_with_bytes_response import GenerateRandomWithBytesResponse
from ahvac.models.generate_random_with_source_and_bytes_request import GenerateRandomWithSourceAndBytesRequest
from ahvac.models.generate_random_with_source_and_bytes_response import GenerateRandomWithSourceAndBytesResponse
from ahvac.models.generate_random_with_source_request import GenerateRandomWithSourceRequest
from ahvac.models.generate_random_with_source_response import GenerateRandomWithSourceResponse
from ahvac.models.github_configure_request import GithubConfigureRequest
from ahvac.models.github_login_request import GithubLoginRequest
from ahvac.models.github_write_team_mapping_request import GithubWriteTeamMappingRequest
from ahvac.models.github_write_user_mapping_request import GithubWriteUserMappingRequest
from ahvac.models.google_cloud_configure_auth_request import GoogleCloudConfigureAuthRequest
from ahvac.models.google_cloud_configure_request import GoogleCloudConfigureRequest
from ahvac.models.google_cloud_edit_labels_for_role_request import GoogleCloudEditLabelsForRoleRequest
from ahvac.models.google_cloud_edit_service_accounts_for_role_request import GoogleCloudEditServiceAccountsForRoleRequest
from ahvac.models.google_cloud_generate_roleset_key3_request import GoogleCloudGenerateRolesetKey3Request
from ahvac.models.google_cloud_generate_roleset_key_request import GoogleCloudGenerateRolesetKeyRequest
from ahvac.models.google_cloud_generate_static_account_key_request import GoogleCloudGenerateStaticAccountKeyRequest
from ahvac.models.google_cloud_kms_configure_key_request import GoogleCloudKmsConfigureKeyRequest
from ahvac.models.google_cloud_kms_configure_request import GoogleCloudKmsConfigureRequest
from ahvac.models.google_cloud_kms_decrypt_request import GoogleCloudKmsDecryptRequest
from ahvac.models.google_cloud_kms_encrypt_request import GoogleCloudKmsEncryptRequest
from ahvac.models.google_cloud_kms_reencrypt_request import GoogleCloudKmsReencryptRequest
from ahvac.models.google_cloud_kms_register_key_request import GoogleCloudKmsRegisterKeyRequest
from ahvac.models.google_cloud_kms_sign_request import GoogleCloudKmsSignRequest
from ahvac.models.google_cloud_kms_verify_request import GoogleCloudKmsVerifyRequest
from ahvac.models.google_cloud_kms_write_key_request import GoogleCloudKmsWriteKeyRequest
from ahvac.models.google_cloud_login_request import GoogleCloudLoginRequest
from ahvac.models.google_cloud_write_impersonated_account_request import GoogleCloudWriteImpersonatedAccountRequest
from ahvac.models.google_cloud_write_role_request import GoogleCloudWriteRoleRequest
from ahvac.models.google_cloud_write_roleset_request import GoogleCloudWriteRolesetRequest
from ahvac.models.google_cloud_write_static_account_request import GoogleCloudWriteStaticAccountRequest
from ahvac.models.group_create_alias_request import GroupCreateAliasRequest
from ahvac.models.group_create_request import GroupCreateRequest
from ahvac.models.group_look_up_request import GroupLookUpRequest
from ahvac.models.group_update_alias_by_id_request import GroupUpdateAliasByIdRequest
from ahvac.models.group_update_by_id_request import GroupUpdateByIdRequest
from ahvac.models.group_update_by_name_request import GroupUpdateByNameRequest
from ahvac.models.ha_status_response import HaStatusResponse
from ahvac.models.initialize_request import InitializeRequest
from ahvac.models.internal_client_activity_configure_request import InternalClientActivityConfigureRequest
from ahvac.models.internal_count_entities_response import InternalCountEntitiesResponse
from ahvac.models.internal_count_tokens_response import InternalCountTokensResponse
from ahvac.models.internal_generate_open_api_document_with_parameters_request import InternalGenerateOpenApiDocumentWithParametersRequest
from ahvac.models.internal_ui_list_enabled_feature_flags_response import InternalUiListEnabledFeatureFlagsResponse
from ahvac.models.internal_ui_list_enabled_visible_mounts_response import InternalUiListEnabledVisibleMountsResponse
from ahvac.models.internal_ui_list_namespaces_response import InternalUiListNamespacesResponse
from ahvac.models.internal_ui_read_mount_information_response import InternalUiReadMountInformationResponse
from ahvac.models.internal_ui_read_resultant_acl_response import InternalUiReadResultantAclResponse
from ahvac.models.jwt_configure_request import JwtConfigureRequest
from ahvac.models.jwt_login_request import JwtLoginRequest
from ahvac.models.jwt_oidc_callback_form_post_request import JwtOidcCallbackFormPostRequest
from ahvac.models.jwt_oidc_request_authorization_url_request import JwtOidcRequestAuthorizationUrlRequest
from ahvac.models.jwt_write_role_request import JwtWriteRoleRequest
from ahvac.models.kerberos_configure_ldap_request import KerberosConfigureLdapRequest
from ahvac.models.kerberos_configure_request import KerberosConfigureRequest
from ahvac.models.kerberos_login_request import KerberosLoginRequest
from ahvac.models.kerberos_write_group_request import KerberosWriteGroupRequest
from ahvac.models.kubernetes_configure_auth_request import KubernetesConfigureAuthRequest
from ahvac.models.kubernetes_configure_request import KubernetesConfigureRequest
from ahvac.models.kubernetes_generate_credentials_request import KubernetesGenerateCredentialsRequest
from ahvac.models.kubernetes_login_request import KubernetesLoginRequest
from ahvac.models.kubernetes_write_auth_role_request import KubernetesWriteAuthRoleRequest
from ahvac.models.kubernetes_write_role_request import KubernetesWriteRoleRequest
from ahvac.models.kv_v2_configure_request import KvV2ConfigureRequest
from ahvac.models.kv_v2_delete_versions_request import KvV2DeleteVersionsRequest
from ahvac.models.kv_v2_destroy_versions_request import KvV2DestroyVersionsRequest
from ahvac.models.kv_v2_patch_response import KvV2PatchResponse
from ahvac.models.kv_v2_read_configuration_response import KvV2ReadConfigurationResponse
from ahvac.models.kv_v2_read_metadata_response import KvV2ReadMetadataResponse
from ahvac.models.kv_v2_read_response import KvV2ReadResponse
from ahvac.models.kv_v2_read_subkeys_response import KvV2ReadSubkeysResponse
from ahvac.models.kv_v2_undelete_versions_request import KvV2UndeleteVersionsRequest
from ahvac.models.kv_v2_write_metadata_request import KvV2WriteMetadataRequest
from ahvac.models.kv_v2_write_request import KvV2WriteRequest
from ahvac.models.kv_v2_write_response import KvV2WriteResponse
from ahvac.models.ldap_configure_auth_request import LdapConfigureAuthRequest
from ahvac.models.ldap_configure_request import LdapConfigureRequest
from ahvac.models.ldap_library_check_in_request import LdapLibraryCheckInRequest
from ahvac.models.ldap_library_check_out_request import LdapLibraryCheckOutRequest
from ahvac.models.ldap_library_configure_request import LdapLibraryConfigureRequest
from ahvac.models.ldap_library_force_check_in_request import LdapLibraryForceCheckInRequest
from ahvac.models.ldap_login_request import LdapLoginRequest
from ahvac.models.ldap_write_dynamic_role_request import LdapWriteDynamicRoleRequest
from ahvac.models.ldap_write_group_request import LdapWriteGroupRequest
from ahvac.models.ldap_write_static_role_request import LdapWriteStaticRoleRequest
from ahvac.models.ldap_write_user_request import LdapWriteUserRequest
from ahvac.models.leader_status_response import LeaderStatusResponse
from ahvac.models.leases_count_response import LeasesCountResponse
from ahvac.models.leases_list_response import LeasesListResponse
from ahvac.models.leases_look_up_response import LeasesLookUpResponse
from ahvac.models.leases_read_lease_request import LeasesReadLeaseRequest
from ahvac.models.leases_read_lease_response import LeasesReadLeaseResponse
from ahvac.models.leases_renew_lease2_request import LeasesRenewLease2Request
from ahvac.models.leases_renew_lease_request import LeasesRenewLeaseRequest
from ahvac.models.leases_renew_lease_with_id2_request import LeasesRenewLeaseWithId2Request
from ahvac.models.leases_renew_lease_with_id_request import LeasesRenewLeaseWithIdRequest
from ahvac.models.leases_revoke_lease2_request import LeasesRevokeLease2Request
from ahvac.models.leases_revoke_lease_request import LeasesRevokeLeaseRequest
from ahvac.models.leases_revoke_lease_with_id2_request import LeasesRevokeLeaseWithId2Request
from ahvac.models.leases_revoke_lease_with_id_request import LeasesRevokeLeaseWithIdRequest
from ahvac.models.leases_revoke_lease_with_prefix2_request import LeasesRevokeLeaseWithPrefix2Request
from ahvac.models.leases_revoke_lease_with_prefix_request import LeasesRevokeLeaseWithPrefixRequest
from ahvac.models.loggers_update_verbosity_level_for_request import LoggersUpdateVerbosityLevelForRequest
from ahvac.models.loggers_update_verbosity_level_request import LoggersUpdateVerbosityLevelRequest
from ahvac.models.mfa_admin_destroy_totp_secret_request import MfaAdminDestroyTotpSecretRequest
from ahvac.models.mfa_admin_generate_totp_secret_request import MfaAdminGenerateTotpSecretRequest
from ahvac.models.mfa_create_duo_method_request import MfaCreateDuoMethodRequest
from ahvac.models.mfa_create_okta_method_request import MfaCreateOktaMethodRequest
from ahvac.models.mfa_create_ping_id_method_request import MfaCreatePingIdMethodRequest
from ahvac.models.mfa_create_totp_method_request import MfaCreateTotpMethodRequest
from ahvac.models.mfa_generate_totp_secret_request import MfaGenerateTotpSecretRequest
from ahvac.models.mfa_update_duo_method_request import MfaUpdateDuoMethodRequest
from ahvac.models.mfa_update_okta_method_request import MfaUpdateOktaMethodRequest
from ahvac.models.mfa_update_ping_id_method_request import MfaUpdatePingIdMethodRequest
from ahvac.models.mfa_update_totp_method_request import MfaUpdateTotpMethodRequest
from ahvac.models.mfa_validate_request import MfaValidateRequest
from ahvac.models.mfa_write_login_enforcement_request import MfaWriteLoginEnforcementRequest
from ahvac.models.mongo_db_atlas_configure_request import MongoDbAtlasConfigureRequest
from ahvac.models.mongo_db_atlas_write_role_request import MongoDbAtlasWriteRoleRequest
from ahvac.models.mounts_enable_secrets_engine_request import MountsEnableSecretsEngineRequest
from ahvac.models.mounts_read_configuration_response import MountsReadConfigurationResponse
from ahvac.models.mounts_read_tuning_information_response import MountsReadTuningInformationResponse
from ahvac.models.mounts_tune_configuration_parameters_request import MountsTuneConfigurationParametersRequest
from ahvac.models.nomad_configure_access_request import NomadConfigureAccessRequest
from ahvac.models.nomad_configure_lease_request import NomadConfigureLeaseRequest
from ahvac.models.nomad_write_role_request import NomadWriteRoleRequest
from ahvac.models.oci_configure_request import OciConfigureRequest
from ahvac.models.oci_login_request import OciLoginRequest
from ahvac.models.oci_write_role_request import OciWriteRoleRequest
from ahvac.models.oidc_configure_request import OidcConfigureRequest
from ahvac.models.oidc_introspect_request import OidcIntrospectRequest
from ahvac.models.oidc_provider_authorize_with_parameters_request import OidcProviderAuthorizeWithParametersRequest
from ahvac.models.oidc_provider_token_request import OidcProviderTokenRequest
from ahvac.models.oidc_rotate_key_request import OidcRotateKeyRequest
from ahvac.models.oidc_write_assignment_request import OidcWriteAssignmentRequest
from ahvac.models.oidc_write_client_request import OidcWriteClientRequest
from ahvac.models.oidc_write_key_request import OidcWriteKeyRequest
from ahvac.models.oidc_write_provider_request import OidcWriteProviderRequest
from ahvac.models.oidc_write_role_request import OidcWriteRoleRequest
from ahvac.models.oidc_write_scope_request import OidcWriteScopeRequest
from ahvac.models.okta_configure_request import OktaConfigureRequest
from ahvac.models.okta_login_request import OktaLoginRequest
from ahvac.models.okta_write_group_request import OktaWriteGroupRequest
from ahvac.models.okta_write_user_request import OktaWriteUserRequest
from ahvac.models.persona_create_request import PersonaCreateRequest
from ahvac.models.persona_update_by_id_request import PersonaUpdateByIdRequest
from ahvac.models.pki_configure_acme_request import PkiConfigureAcmeRequest
from ahvac.models.pki_configure_auto_tidy_request import PkiConfigureAutoTidyRequest
from ahvac.models.pki_configure_auto_tidy_response import PkiConfigureAutoTidyResponse
from ahvac.models.pki_configure_ca_request import PkiConfigureCaRequest
from ahvac.models.pki_configure_ca_response import PkiConfigureCaResponse
from ahvac.models.pki_configure_cluster_request import PkiConfigureClusterRequest
from ahvac.models.pki_configure_cluster_response import PkiConfigureClusterResponse
from ahvac.models.pki_configure_crl_request import PkiConfigureCrlRequest
from ahvac.models.pki_configure_crl_response import PkiConfigureCrlResponse
from ahvac.models.pki_configure_issuers_request import PkiConfigureIssuersRequest
from ahvac.models.pki_configure_issuers_response import PkiConfigureIssuersResponse
from ahvac.models.pki_configure_keys_request import PkiConfigureKeysRequest
from ahvac.models.pki_configure_keys_response import PkiConfigureKeysResponse
from ahvac.models.pki_configure_urls_request import PkiConfigureUrlsRequest
from ahvac.models.pki_configure_urls_response import PkiConfigureUrlsResponse
from ahvac.models.pki_cross_sign_intermediate_request import PkiCrossSignIntermediateRequest
from ahvac.models.pki_cross_sign_intermediate_response import PkiCrossSignIntermediateResponse
from ahvac.models.pki_generate_eab_key_for_issuer_and_role_response import PkiGenerateEabKeyForIssuerAndRoleResponse
from ahvac.models.pki_generate_eab_key_for_issuer_response import PkiGenerateEabKeyForIssuerResponse
from ahvac.models.pki_generate_eab_key_for_role_response import PkiGenerateEabKeyForRoleResponse
from ahvac.models.pki_generate_eab_key_response import PkiGenerateEabKeyResponse
from ahvac.models.pki_generate_exported_key_request import PkiGenerateExportedKeyRequest
from ahvac.models.pki_generate_exported_key_response import PkiGenerateExportedKeyResponse
from ahvac.models.pki_generate_intermediate_request import PkiGenerateIntermediateRequest
from ahvac.models.pki_generate_intermediate_response import PkiGenerateIntermediateResponse
from ahvac.models.pki_generate_internal_key_request import PkiGenerateInternalKeyRequest
from ahvac.models.pki_generate_internal_key_response import PkiGenerateInternalKeyResponse
from ahvac.models.pki_generate_kms_key_request import PkiGenerateKmsKeyRequest
from ahvac.models.pki_generate_kms_key_response import PkiGenerateKmsKeyResponse
from ahvac.models.pki_generate_root_request import PkiGenerateRootRequest
from ahvac.models.pki_generate_root_response import PkiGenerateRootResponse
from ahvac.models.pki_import_key_request import PkiImportKeyRequest
from ahvac.models.pki_import_key_response import PkiImportKeyResponse
from ahvac.models.pki_issue_with_role_request import PkiIssueWithRoleRequest
from ahvac.models.pki_issue_with_role_response import PkiIssueWithRoleResponse
from ahvac.models.pki_issuer_issue_with_role_request import PkiIssuerIssueWithRoleRequest
from ahvac.models.pki_issuer_issue_with_role_response import PkiIssuerIssueWithRoleResponse
from ahvac.models.pki_issuer_read_crl_delta_der_response import PkiIssuerReadCrlDeltaDerResponse
from ahvac.models.pki_issuer_read_crl_delta_pem_response import PkiIssuerReadCrlDeltaPemResponse
from ahvac.models.pki_issuer_read_crl_delta_response import PkiIssuerReadCrlDeltaResponse
from ahvac.models.pki_issuer_read_crl_der_response import PkiIssuerReadCrlDerResponse
from ahvac.models.pki_issuer_read_crl_pem_response import PkiIssuerReadCrlPemResponse
from ahvac.models.pki_issuer_read_crl_response import PkiIssuerReadCrlResponse
from ahvac.models.pki_issuer_resign_crls_request import PkiIssuerResignCrlsRequest
from ahvac.models.pki_issuer_resign_crls_response import PkiIssuerResignCrlsResponse
from ahvac.models.pki_issuer_sign_intermediate_request import PkiIssuerSignIntermediateRequest
from ahvac.models.pki_issuer_sign_intermediate_response import PkiIssuerSignIntermediateResponse
from ahvac.models.pki_issuer_sign_revocation_list_request import PkiIssuerSignRevocationListRequest
from ahvac.models.pki_issuer_sign_revocation_list_response import PkiIssuerSignRevocationListResponse
from ahvac.models.pki_issuer_sign_self_issued_request import PkiIssuerSignSelfIssuedRequest
from ahvac.models.pki_issuer_sign_self_issued_response import PkiIssuerSignSelfIssuedResponse
from ahvac.models.pki_issuer_sign_verbatim_request import PkiIssuerSignVerbatimRequest
from ahvac.models.pki_issuer_sign_verbatim_response import PkiIssuerSignVerbatimResponse
from ahvac.models.pki_issuer_sign_verbatim_with_role_request import PkiIssuerSignVerbatimWithRoleRequest
from ahvac.models.pki_issuer_sign_verbatim_with_role_response import PkiIssuerSignVerbatimWithRoleResponse
from ahvac.models.pki_issuer_sign_with_role_request import PkiIssuerSignWithRoleRequest
from ahvac.models.pki_issuer_sign_with_role_response import PkiIssuerSignWithRoleResponse
from ahvac.models.pki_issuers_generate_intermediate_request import PkiIssuersGenerateIntermediateRequest
from ahvac.models.pki_issuers_generate_intermediate_response import PkiIssuersGenerateIntermediateResponse
from ahvac.models.pki_issuers_generate_root_request import PkiIssuersGenerateRootRequest
from ahvac.models.pki_issuers_generate_root_response import PkiIssuersGenerateRootResponse
from ahvac.models.pki_issuers_import_bundle_request import PkiIssuersImportBundleRequest
from ahvac.models.pki_issuers_import_bundle_response import PkiIssuersImportBundleResponse
from ahvac.models.pki_issuers_import_cert_request import PkiIssuersImportCertRequest
from ahvac.models.pki_issuers_import_cert_response import PkiIssuersImportCertResponse
from ahvac.models.pki_list_eab_keys_response import PkiListEabKeysResponse
from ahvac.models.pki_list_issuers_response import PkiListIssuersResponse
from ahvac.models.pki_list_keys_response import PkiListKeysResponse
from ahvac.models.pki_patch_issuer_response import PkiPatchIssuerResponse
from ahvac.models.pki_patch_role_response import PkiPatchRoleResponse
from ahvac.models.pki_read_auto_tidy_configuration_response import PkiReadAutoTidyConfigurationResponse
from ahvac.models.pki_read_ca_chain_pem_response import PkiReadCaChainPemResponse
from ahvac.models.pki_read_ca_der_response import PkiReadCaDerResponse
from ahvac.models.pki_read_ca_pem_response import PkiReadCaPemResponse
from ahvac.models.pki_read_cert_ca_chain_response import PkiReadCertCaChainResponse
from ahvac.models.pki_read_cert_crl_response import PkiReadCertCrlResponse
from ahvac.models.pki_read_cert_delta_crl_response import PkiReadCertDeltaCrlResponse
from ahvac.models.pki_read_cert_raw_der_response import PkiReadCertRawDerResponse
from ahvac.models.pki_read_cert_raw_pem_response import PkiReadCertRawPemResponse
from ahvac.models.pki_read_cert_response import PkiReadCertResponse
from ahvac.models.pki_read_cluster_configuration_response import PkiReadClusterConfigurationResponse
from ahvac.models.pki_read_crl_configuration_response import PkiReadCrlConfigurationResponse
from ahvac.models.pki_read_crl_delta_pem_response import PkiReadCrlDeltaPemResponse
from ahvac.models.pki_read_crl_delta_response import PkiReadCrlDeltaResponse
from ahvac.models.pki_read_crl_der_response import PkiReadCrlDerResponse
from ahvac.models.pki_read_crl_pem_response import PkiReadCrlPemResponse
from ahvac.models.pki_read_issuer_der_response import PkiReadIssuerDerResponse
from ahvac.models.pki_read_issuer_json_response import PkiReadIssuerJsonResponse
from ahvac.models.pki_read_issuer_pem_response import PkiReadIssuerPemResponse
from ahvac.models.pki_read_issuer_response import PkiReadIssuerResponse
from ahvac.models.pki_read_issuers_configuration_response import PkiReadIssuersConfigurationResponse
from ahvac.models.pki_read_key_response import PkiReadKeyResponse
from ahvac.models.pki_read_keys_configuration_response import PkiReadKeysConfigurationResponse
from ahvac.models.pki_read_role_response import PkiReadRoleResponse
from ahvac.models.pki_read_urls_configuration_response import PkiReadUrlsConfigurationResponse
from ahvac.models.pki_replace_root_request import PkiReplaceRootRequest
from ahvac.models.pki_replace_root_response import PkiReplaceRootResponse
from ahvac.models.pki_revoke_issuer_response import PkiRevokeIssuerResponse
from ahvac.models.pki_revoke_request import PkiRevokeRequest
from ahvac.models.pki_revoke_response import PkiRevokeResponse
from ahvac.models.pki_revoke_with_key_request import PkiRevokeWithKeyRequest
from ahvac.models.pki_revoke_with_key_response import PkiRevokeWithKeyResponse
from ahvac.models.pki_root_sign_intermediate_request import PkiRootSignIntermediateRequest
from ahvac.models.pki_root_sign_intermediate_response import PkiRootSignIntermediateResponse
from ahvac.models.pki_root_sign_self_issued_request import PkiRootSignSelfIssuedRequest
from ahvac.models.pki_root_sign_self_issued_response import PkiRootSignSelfIssuedResponse
from ahvac.models.pki_rotate_crl_response import PkiRotateCrlResponse
from ahvac.models.pki_rotate_delta_crl_response import PkiRotateDeltaCrlResponse
from ahvac.models.pki_rotate_root_request import PkiRotateRootRequest
from ahvac.models.pki_rotate_root_response import PkiRotateRootResponse
from ahvac.models.pki_set_signed_intermediate_request import PkiSetSignedIntermediateRequest
from ahvac.models.pki_set_signed_intermediate_response import PkiSetSignedIntermediateResponse
from ahvac.models.pki_sign_verbatim_request import PkiSignVerbatimRequest
from ahvac.models.pki_sign_verbatim_response import PkiSignVerbatimResponse
from ahvac.models.pki_sign_verbatim_with_role_request import PkiSignVerbatimWithRoleRequest
from ahvac.models.pki_sign_verbatim_with_role_response import PkiSignVerbatimWithRoleResponse
from ahvac.models.pki_sign_with_role_request import PkiSignWithRoleRequest
from ahvac.models.pki_sign_with_role_response import PkiSignWithRoleResponse
from ahvac.models.pki_tidy_cancel_response import PkiTidyCancelResponse
from ahvac.models.pki_tidy_request import PkiTidyRequest
from ahvac.models.pki_tidy_status_response import PkiTidyStatusResponse
from ahvac.models.pki_write_acme_account_kid_request import PkiWriteAcmeAccountKidRequest
from ahvac.models.pki_write_acme_authorization_auth_id_request import PkiWriteAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_acme_challenge_auth_id_challenge_type_request import PkiWriteAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_acme_new_account_request import PkiWriteAcmeNewAccountRequest
from ahvac.models.pki_write_acme_new_order_request import PkiWriteAcmeNewOrderRequest
from ahvac.models.pki_write_acme_order_order_id_cert_request import PkiWriteAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_acme_order_order_id_finalize_request import PkiWriteAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_acme_order_order_id_request import PkiWriteAcmeOrderOrderIdRequest
from ahvac.models.pki_write_acme_orders_request import PkiWriteAcmeOrdersRequest
from ahvac.models.pki_write_acme_revoke_cert_request import PkiWriteAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_account_kid_request import PkiWriteIssuerIssuerRefAcmeAccountKidRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_authorization_auth_id_request import PkiWriteIssuerIssuerRefAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_challenge_auth_id_challenge_type_request import PkiWriteIssuerIssuerRefAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_new_account_request import PkiWriteIssuerIssuerRefAcmeNewAccountRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_new_order_request import PkiWriteIssuerIssuerRefAcmeNewOrderRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_cert_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_finalize_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_order_order_id_request import PkiWriteIssuerIssuerRefAcmeOrderOrderIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_orders_request import PkiWriteIssuerIssuerRefAcmeOrdersRequest
from ahvac.models.pki_write_issuer_issuer_ref_acme_revoke_cert_request import PkiWriteIssuerIssuerRefAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_account_kid_request import PkiWriteIssuerIssuerRefRolesRoleAcmeAccountKidRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_authorization_auth_id_request import PkiWriteIssuerIssuerRefRolesRoleAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_challenge_auth_id_challenge_type_request import PkiWriteIssuerIssuerRefRolesRoleAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_new_account_request import PkiWriteIssuerIssuerRefRolesRoleAcmeNewAccountRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_new_order_request import PkiWriteIssuerIssuerRefRolesRoleAcmeNewOrderRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_cert_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_finalize_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_order_order_id_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrderOrderIdRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_orders_request import PkiWriteIssuerIssuerRefRolesRoleAcmeOrdersRequest
from ahvac.models.pki_write_issuer_issuer_ref_roles_role_acme_revoke_cert_request import PkiWriteIssuerIssuerRefRolesRoleAcmeRevokeCertRequest
from ahvac.models.pki_write_issuer_request import PkiWriteIssuerRequest
from ahvac.models.pki_write_issuer_response import PkiWriteIssuerResponse
from ahvac.models.pki_write_key_request import PkiWriteKeyRequest
from ahvac.models.pki_write_key_response import PkiWriteKeyResponse
from ahvac.models.pki_write_role_request import PkiWriteRoleRequest
from ahvac.models.pki_write_role_response import PkiWriteRoleResponse
from ahvac.models.pki_write_roles_role_acme_account_kid_request import PkiWriteRolesRoleAcmeAccountKidRequest
from ahvac.models.pki_write_roles_role_acme_authorization_auth_id_request import PkiWriteRolesRoleAcmeAuthorizationAuthIdRequest
from ahvac.models.pki_write_roles_role_acme_challenge_auth_id_challenge_type_request import PkiWriteRolesRoleAcmeChallengeAuthIdChallengeTypeRequest
from ahvac.models.pki_write_roles_role_acme_new_account_request import PkiWriteRolesRoleAcmeNewAccountRequest
from ahvac.models.pki_write_roles_role_acme_new_order_request import PkiWriteRolesRoleAcmeNewOrderRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_cert_request import PkiWriteRolesRoleAcmeOrderOrderIdCertRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_finalize_request import PkiWriteRolesRoleAcmeOrderOrderIdFinalizeRequest
from ahvac.models.pki_write_roles_role_acme_order_order_id_request import PkiWriteRolesRoleAcmeOrderOrderIdRequest
from ahvac.models.pki_write_roles_role_acme_orders_request import PkiWriteRolesRoleAcmeOrdersRequest
from ahvac.models.pki_write_roles_role_acme_revoke_cert_request import PkiWriteRolesRoleAcmeRevokeCertRequest
from ahvac.models.plugins_catalog_list_plugins_response import PluginsCatalogListPluginsResponse
from ahvac.models.plugins_catalog_list_plugins_with_type_response import PluginsCatalogListPluginsWithTypeResponse
from ahvac.models.plugins_catalog_read_plugin_configuration_response import PluginsCatalogReadPluginConfigurationResponse
from ahvac.models.plugins_catalog_read_plugin_configuration_with_type_response import PluginsCatalogReadPluginConfigurationWithTypeResponse
from ahvac.models.plugins_catalog_register_plugin_request import PluginsCatalogRegisterPluginRequest
from ahvac.models.plugins_catalog_register_plugin_with_type_request import PluginsCatalogRegisterPluginWithTypeRequest
from ahvac.models.plugins_reload_backends_request import PluginsReloadBackendsRequest
from ahvac.models.plugins_reload_backends_response import PluginsReloadBackendsResponse
from ahvac.models.plugins_runtimes_catalog_list_plugins_runtimes_response import PluginsRuntimesCatalogListPluginsRuntimesResponse
from ahvac.models.plugins_runtimes_catalog_read_plugin_runtime_configuration_response import PluginsRuntimesCatalogReadPluginRuntimeConfigurationResponse
from ahvac.models.plugins_runtimes_catalog_register_plugin_runtime_request import PluginsRuntimesCatalogRegisterPluginRuntimeRequest
from ahvac.models.policies_generate_password_from_password_policy_response import PoliciesGeneratePasswordFromPasswordPolicyResponse
from ahvac.models.policies_list_acl_policies2_response import PoliciesListAclPolicies2Response
from ahvac.models.policies_list_acl_policies3_response import PoliciesListAclPolicies3Response
from ahvac.models.policies_list_acl_policies_response import PoliciesListAclPoliciesResponse
from ahvac.models.policies_read_acl_policy2_response import PoliciesReadAclPolicy2Response
from ahvac.models.policies_read_acl_policy_response import PoliciesReadAclPolicyResponse
from ahvac.models.policies_read_password_policy_response import PoliciesReadPasswordPolicyResponse
from ahvac.models.policies_write_acl_policy2_request import PoliciesWriteAclPolicy2Request
from ahvac.models.policies_write_acl_policy_request import PoliciesWriteAclPolicyRequest
from ahvac.models.policies_write_password_policy_request import PoliciesWritePasswordPolicyRequest
from ahvac.models.query_token_accessor_capabilities_request import QueryTokenAccessorCapabilitiesRequest
from ahvac.models.query_token_capabilities_request import QueryTokenCapabilitiesRequest
from ahvac.models.query_token_self_capabilities_request import QueryTokenSelfCapabilitiesRequest
from ahvac.models.rabbit_mq_configure_connection_request import RabbitMqConfigureConnectionRequest
from ahvac.models.rabbit_mq_configure_lease_request import RabbitMqConfigureLeaseRequest
from ahvac.models.rabbit_mq_write_role_request import RabbitMqWriteRoleRequest
from ahvac.models.radius_configure_request import RadiusConfigureRequest
from ahvac.models.radius_login_request import RadiusLoginRequest
from ahvac.models.radius_login_with_username_request import RadiusLoginWithUsernameRequest
from ahvac.models.radius_write_user_request import RadiusWriteUserRequest
from ahvac.models.rate_limit_quotas_configure_request import RateLimitQuotasConfigureRequest
from ahvac.models.rate_limit_quotas_read_configuration_response import RateLimitQuotasReadConfigurationResponse
from ahvac.models.rate_limit_quotas_read_response import RateLimitQuotasReadResponse
from ahvac.models.rate_limit_quotas_write_request import RateLimitQuotasWriteRequest
from ahvac.models.raw_read_response import RawReadResponse
from ahvac.models.raw_write_request import RawWriteRequest
from ahvac.models.read_wrapping_properties2_response import ReadWrappingProperties2Response
from ahvac.models.read_wrapping_properties_request import ReadWrappingPropertiesRequest
from ahvac.models.read_wrapping_properties_response import ReadWrappingPropertiesResponse
from ahvac.models.rekey_attempt_initialize_request import RekeyAttemptInitializeRequest
from ahvac.models.rekey_attempt_initialize_response import RekeyAttemptInitializeResponse
from ahvac.models.rekey_attempt_read_progress_response import RekeyAttemptReadProgressResponse
from ahvac.models.rekey_attempt_update_request import RekeyAttemptUpdateRequest
from ahvac.models.rekey_attempt_update_response import RekeyAttemptUpdateResponse
from ahvac.models.rekey_read_backup_key_response import RekeyReadBackupKeyResponse
from ahvac.models.rekey_read_backup_recovery_key_response import RekeyReadBackupRecoveryKeyResponse
from ahvac.models.rekey_verification_cancel_response import RekeyVerificationCancelResponse
from ahvac.models.rekey_verification_read_progress_response import RekeyVerificationReadProgressResponse
from ahvac.models.rekey_verification_update_request import RekeyVerificationUpdateRequest
from ahvac.models.rekey_verification_update_response import RekeyVerificationUpdateResponse
from ahvac.models.remount_request import RemountRequest
from ahvac.models.remount_response import RemountResponse
from ahvac.models.remount_status_response import RemountStatusResponse
from ahvac.models.rewrap_request import RewrapRequest
from ahvac.models.root_token_generation_initialize2_request import RootTokenGenerationInitialize2Request
from ahvac.models.root_token_generation_initialize2_response import RootTokenGenerationInitialize2Response
from ahvac.models.root_token_generation_initialize_request import RootTokenGenerationInitializeRequest
from ahvac.models.root_token_generation_initialize_response import RootTokenGenerationInitializeResponse
from ahvac.models.root_token_generation_read_progress2_response import RootTokenGenerationReadProgress2Response
from ahvac.models.root_token_generation_read_progress_response import RootTokenGenerationReadProgressResponse
from ahvac.models.root_token_generation_update_request import RootTokenGenerationUpdateRequest
from ahvac.models.root_token_generation_update_response import RootTokenGenerationUpdateResponse
from ahvac.models.seal_status_response import SealStatusResponse
from ahvac.models.ssh_configure_ca_request import SshConfigureCaRequest
from ahvac.models.ssh_configure_zero_address_request import SshConfigureZeroAddressRequest
from ahvac.models.ssh_generate_credentials_request import SshGenerateCredentialsRequest
from ahvac.models.ssh_issue_certificate_request import SshIssueCertificateRequest
from ahvac.models.ssh_list_roles_by_ip_request import SshListRolesByIpRequest
from ahvac.models.ssh_sign_certificate_request import SshSignCertificateRequest
from ahvac.models.ssh_verify_otp_request import SshVerifyOtpRequest
from ahvac.models.ssh_write_role_request import SshWriteRoleRequest
from ahvac.models.standard_list_response import StandardListResponse
from ahvac.models.terraform_cloud_configure_request import TerraformCloudConfigureRequest
from ahvac.models.terraform_cloud_write_role_request import TerraformCloudWriteRoleRequest
from ahvac.models.token_create_against_role_request import TokenCreateAgainstRoleRequest
from ahvac.models.token_create_orphan_request import TokenCreateOrphanRequest
from ahvac.models.token_create_request import TokenCreateRequest
from ahvac.models.token_look_up_accessor_request import TokenLookUpAccessorRequest
from ahvac.models.token_look_up_request import TokenLookUpRequest
from ahvac.models.token_look_up_self2_request import TokenLookUpSelf2Request
from ahvac.models.token_renew_accessor_request import TokenRenewAccessorRequest
from ahvac.models.token_renew_request import TokenRenewRequest
from ahvac.models.token_renew_self_request import TokenRenewSelfRequest
from ahvac.models.token_revoke_accessor_request import TokenRevokeAccessorRequest
from ahvac.models.token_revoke_orphan_request import TokenRevokeOrphanRequest
from ahvac.models.token_revoke_request import TokenRevokeRequest
from ahvac.models.token_write_role_request import TokenWriteRoleRequest
from ahvac.models.totp_create_key_request import TotpCreateKeyRequest
from ahvac.models.totp_validate_code_request import TotpValidateCodeRequest
from ahvac.models.transit_configure_cache_request import TransitConfigureCacheRequest
from ahvac.models.transit_configure_key_request import TransitConfigureKeyRequest
from ahvac.models.transit_configure_keys_request import TransitConfigureKeysRequest
from ahvac.models.transit_create_key_request import TransitCreateKeyRequest
from ahvac.models.transit_decrypt_request import TransitDecryptRequest
from ahvac.models.transit_encrypt_request import TransitEncryptRequest
from ahvac.models.transit_generate_csr_for_key_request import TransitGenerateCsrForKeyRequest
from ahvac.models.transit_generate_data_key_request import TransitGenerateDataKeyRequest
from ahvac.models.transit_generate_hmac_request import TransitGenerateHmacRequest
from ahvac.models.transit_generate_hmac_with_algorithm_request import TransitGenerateHmacWithAlgorithmRequest
from ahvac.models.transit_generate_random_request import TransitGenerateRandomRequest
from ahvac.models.transit_generate_random_with_bytes_request import TransitGenerateRandomWithBytesRequest
from ahvac.models.transit_generate_random_with_source_and_bytes_request import TransitGenerateRandomWithSourceAndBytesRequest
from ahvac.models.transit_generate_random_with_source_request import TransitGenerateRandomWithSourceRequest
from ahvac.models.transit_hash_request import TransitHashRequest
from ahvac.models.transit_hash_with_algorithm_request import TransitHashWithAlgorithmRequest
from ahvac.models.transit_import_key_request import TransitImportKeyRequest
from ahvac.models.transit_import_key_version_request import TransitImportKeyVersionRequest
from ahvac.models.transit_restore_and_rename_key_request import TransitRestoreAndRenameKeyRequest
from ahvac.models.transit_restore_key_request import TransitRestoreKeyRequest
from ahvac.models.transit_rewrap_request import TransitRewrapRequest
from ahvac.models.transit_rotate_key_request import TransitRotateKeyRequest
from ahvac.models.transit_set_certificate_for_key_request import TransitSetCertificateForKeyRequest
from ahvac.models.transit_sign_request import TransitSignRequest
from ahvac.models.transit_sign_with_algorithm_request import TransitSignWithAlgorithmRequest
from ahvac.models.transit_trim_key_request import TransitTrimKeyRequest
from ahvac.models.transit_verify_request import TransitVerifyRequest
from ahvac.models.transit_verify_with_algorithm_request import TransitVerifyWithAlgorithmRequest
from ahvac.models.ui_headers_configure_request import UiHeadersConfigureRequest
from ahvac.models.ui_headers_list_response import UiHeadersListResponse
from ahvac.models.ui_headers_read_configuration_response import UiHeadersReadConfigurationResponse
from ahvac.models.unseal_request import UnsealRequest
from ahvac.models.unseal_response import UnsealResponse
from ahvac.models.unwrap_request import UnwrapRequest
from ahvac.models.userpass_login_request import UserpassLoginRequest
from ahvac.models.userpass_reset_password_request import UserpassResetPasswordRequest
from ahvac.models.userpass_update_policies_request import UserpassUpdatePoliciesRequest
from ahvac.models.userpass_write_user_request import UserpassWriteUserRequest
from ahvac.models.version_history_response import VersionHistoryResponse



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.cloud_foundry_configure_request import CloudFoundryConfigureRequest

class TestCloudFoundryConfigureRequest(unittest.TestCase):
    """CloudFoundryConfigureRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CloudFoundryConfigureRequest:
        """Test CloudFoundryConfigureRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CloudFoundryConfigureRequest`
        """
        model = CloudFoundryConfigureRequest()
        if include_optional:
            return CloudFoundryConfigureRequest(
                cf_api_addr = '',
                cf_api_mutual_tls_certificate = '',
                cf_api_mutual_tls_key = '',
                cf_api_trusted_certificates = [
                    ''
                    ],
                cf_client_id = '',
                cf_client_secret = '',
                cf_password = '',
                cf_username = '',
                identity_ca_certificates = [
                    ''
                    ],
                login_max_seconds_not_after = 56,
                login_max_seconds_not_before = '300',
                pcf_api_addr = '',
                pcf_api_trusted_certificates = [
                    ''
                    ],
                pcf_password = '',
                pcf_username = ''
            )
        else:
            return CloudFoundryConfigureRequest(
        )
        """

    def testCloudFoundryConfigureRequest(self):
        """Test CloudFoundryConfigureRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiConfigureAutoTidyResponse(BaseModel):
    """
    PkiConfigureAutoTidyResponse
    """ # noqa: E501
    acme_account_safety_buffer: Optional[StrictInt] = Field(default=None, description="Safety buffer after creation after which accounts lacking orders are revoked")
    enabled: Optional[StrictBool] = Field(default=None, description="Specifies whether automatic tidy is enabled or not")
    interval_duration: Optional[StrictInt] = Field(default=None, description="Specifies the duration between automatic tidy operation")
    issuer_safety_buffer: Optional[StrictInt] = Field(default=None, description="Issuer safety buffer")
    maintain_stored_certificate_counts: Optional[StrictBool] = None
    pause_duration: Optional[StrictStr] = Field(default=None, description="Duration to pause between tidying certificates")
    publish_stored_certificate_count_metrics: Optional[StrictBool] = None
    revocation_queue_safety_buffer: Optional[StrictInt] = None
    safety_buffer: Optional[StrictInt] = Field(default=None, description="Safety buffer time duration")
    tidy_acme: Optional[StrictBool] = Field(default=None, description="Tidy Unused Acme Accounts, and Orders")
    tidy_cert_store: Optional[StrictBool] = Field(default=None, description="Specifies whether to tidy up the certificate store")
    tidy_cross_cluster_revoked_certs: Optional[StrictBool] = Field(default=None, description="Tidy the cross-cluster revoked certificate store")
    tidy_expired_issuers: Optional[StrictBool] = Field(default=None, description="Specifies whether tidy expired issuers")
    tidy_move_legacy_ca_bundle: Optional[StrictBool] = None
    tidy_revocation_queue: Optional[StrictBool] = None
    tidy_revoked_cert_issuer_associations: Optional[StrictBool] = Field(default=None, description="Specifies whether to associate revoked certificates with their corresponding issuers")
    tidy_revoked_certs: Optional[StrictBool] = Field(default=None, description="Specifies whether to remove all invalid and expired certificates from storage")
    __properties: ClassVar[List[str]] = ["acme_account_safety_buffer", "enabled", "interval_duration", "issuer_safety_buffer", "maintain_stored_certificate_counts", "pause_duration", "publish_stored_certificate_count_metrics", "revocation_queue_safety_buffer", "safety_buffer", "tidy_acme", "tidy_cert_store", "tidy_cross_cluster_revoked_certs", "tidy_expired_issuers", "tidy_move_legacy_ca_bundle", "tidy_revocation_queue", "tidy_revoked_cert_issuer_associations", "tidy_revoked_certs"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiConfigureAutoTidyResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiConfigureAutoTidyResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "acme_account_safety_buffer": obj.get("acme_account_safety_buffer"),
            "enabled": obj.get("enabled"),
            "interval_duration": obj.get("interval_duration"),
            "issuer_safety_buffer": obj.get("issuer_safety_buffer"),
            "maintain_stored_certificate_counts": obj.get("maintain_stored_certificate_counts"),
            "pause_duration": obj.get("pause_duration"),
            "publish_stored_certificate_count_metrics": obj.get("publish_stored_certificate_count_metrics"),
            "revocation_queue_safety_buffer": obj.get("revocation_queue_safety_buffer"),
            "safety_buffer": obj.get("safety_buffer"),
            "tidy_acme": obj.get("tidy_acme"),
            "tidy_cert_store": obj.get("tidy_cert_store"),
            "tidy_cross_cluster_revoked_certs": obj.get("tidy_cross_cluster_revoked_certs"),
            "tidy_expired_issuers": obj.get("tidy_expired_issuers"),
            "tidy_move_legacy_ca_bundle": obj.get("tidy_move_legacy_ca_bundle"),
            "tidy_revocation_queue": obj.get("tidy_revocation_queue"),
            "tidy_revoked_cert_issuer_associations": obj.get("tidy_revoked_cert_issuer_associations"),
            "tidy_revoked_certs": obj.get("tidy_revoked_certs")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.mounts_read_tuning_information_response import MountsReadTuningInformationResponse

class TestMountsReadTuningInformationResponse(unittest.TestCase):
    """MountsReadTuningInformationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MountsReadTuningInformationResponse:
        """Test MountsReadTuningInformationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MountsReadTuningInformationResponse`
        """
        model = MountsReadTuningInformationResponse()
        if include_optional:
            return MountsReadTuningInformationResponse(
                allowed_managed_keys = [
                    ''
                    ],
                allowed_response_headers = [
                    ''
                    ],
                audit_non_hmac_request_keys = [
                    ''
                    ],
                audit_non_hmac_response_keys = [
                    ''
                    ],
                default_lease_ttl = 56,
                description = '',
                external_entropy_access = True,
                force_no_cache = True,
                listing_visibility = '',
                max_lease_ttl = 56,
                options = None,
                passthrough_request_headers = [
                    ''
                    ],
                plugin_version = '',
                token_type = '',
                user_lockout_counter_reset_duration = 56,
                user_lockout_disable = True,
                user_lockout_duration = 56,
                user_lockout_threshold = 56
            )
        else:
            return MountsReadTuningInformationResponse(
        )
        """

    def testMountsReadTuningInformationResponse(self):
        """Test MountsReadTuningInformationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class JwtConfigureRequest(BaseModel):
    """
    JwtConfigureRequest
    """ # noqa: E501
    bound_issuer: Optional[StrictStr] = Field(default=None, description="The value against which to match the 'iss' claim in a JWT. Optional.")
    default_role: Optional[StrictStr] = Field(default=None, description="The default role to use if none is provided during login. If not set, a role is required during login.")
    jwks_ca_pem: Optional[StrictStr] = Field(default=None, description="The CA certificate or chain of certificates, in PEM format, to use to validate connections to the JWKS URL. If not set, system certificates are used.")
    jwks_url: Optional[StrictStr] = Field(default=None, description="JWKS URL to use to authenticate signatures. Cannot be used with \"oidc_discovery_url\" or \"jwt_validation_pubkeys\".")
    jwt_supported_algs: Optional[List[StrictStr]] = Field(default=None, description="A list of supported signing algorithms. Defaults to RS256.")
    jwt_validation_pubkeys: Optional[List[StrictStr]] = Field(default=None, description="A list of PEM-encoded public keys to use to authenticate signatures locally. Cannot be used with \"jwks_url\" or \"oidc_discovery_url\".")
    namespace_in_state: Optional[StrictBool] = Field(default=None, description="Pass namespace in the OIDC state parameter instead of as a separate query parameter. With this setting, the allowed redirect URL(s) in Vault and on the provider side should not contain a namespace query parameter. This means only one redirect URL entry needs to be maintained on the provider side for all vault namespaces that will be authenticating against it. Defaults to true for new configs.")
    oidc_client_id: Optional[StrictStr] = Field(default=None, description="The OAuth Client ID configured with your OIDC provider.")
    oidc_client_secret: Optional[StrictStr] = Field(default=None, description="The OAuth Client Secret configured with your OIDC provider.")
    oidc_discovery_ca_pem: Optional[StrictStr] = Field(default=None, description="The CA certificate or chain of certificates, in PEM format, to use to validate connections to the OIDC Discovery URL. If not set, system certificates are used.")
    oidc_discovery_url: Optional[StrictStr] = Field(default=None, description="OIDC Discovery URL, without any .well-known component (base path). Cannot be used with \"jwks_url\" or \"jwt_validation_pubkeys\".")
    oidc_response_mode: Optional[StrictStr] = Field(default=None, description="The response mode to be used in the OAuth2 request. Allowed values are 'query' and 'form_post'.")
    oidc_response_types: Optional[List[StrictStr]] = Field(default=None, description="The response types to request. Allowed values are 'code' and 'id_token'. Defaults to 'code'.")
    provider_config: Optional[Dict[str, Any]] = Field(default=None, description="Provider-specific configuration. Optional.")
    __properties: ClassVar[List[str]] = ["bound_issuer", "default_role", "jwks_ca_pem", "jwks_url", "jwt_supported_algs", "jwt_validation_pubkeys", "namespace_in_state", "oidc_client_id", "oidc_client_secret", "oidc_discovery_ca_pem", "oidc_discovery_url", "oidc_response_mode", "oidc_response_types", "provider_config"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of JwtConfigureRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of JwtConfigureRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bound_issuer": obj.get("bound_issuer"),
            "default_role": obj.get("default_role"),
            "jwks_ca_pem": obj.get("jwks_ca_pem"),
            "jwks_url": obj.get("jwks_url"),
            "jwt_supported_algs": obj.get("jwt_supported_algs"),
            "jwt_validation_pubkeys": obj.get("jwt_validation_pubkeys"),
            "namespace_in_state": obj.get("namespace_in_state"),
            "oidc_client_id": obj.get("oidc_client_id"),
            "oidc_client_secret": obj.get("oidc_client_secret"),
            "oidc_discovery_ca_pem": obj.get("oidc_discovery_ca_pem"),
            "oidc_discovery_url": obj.get("oidc_discovery_url"),
            "oidc_response_mode": obj.get("oidc_response_mode"),
            "oidc_response_types": obj.get("oidc_response_types"),
            "provider_config": obj.get("provider_config")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TransitDecryptRequest(BaseModel):
    """
    TransitDecryptRequest
    """ # noqa: E501
    associated_data: Optional[StrictStr] = Field(default=None, description="When using an AEAD cipher mode, such as AES-GCM, this parameter allows passing associated data (AD/AAD) into the encryption function; this data must be passed on subsequent decryption requests but can be transited in plaintext. On successful decryption, both the ciphertext and the associated data are attested not to have been tampered with.")
    batch_input: Optional[List[Dict[str, Any]]] = Field(default=None, description="Specifies a list of items to be decrypted in a single batch. When this parameter is set, if the parameters 'ciphertext', 'context' and 'nonce' are also set, they will be ignored. Any batch output will preserve the order of the batch input.")
    ciphertext: Optional[StrictStr] = Field(default=None, description="The ciphertext to decrypt, provided as returned by encrypt.")
    context: Optional[StrictStr] = Field(default=None, description="Base64 encoded context for key derivation. Required if key derivation is enabled.")
    nonce: Optional[StrictStr] = Field(default=None, description="Base64 encoded nonce value used during encryption. Must be provided if convergent encryption is enabled for this key and the key was generated with Vault 0.6.1. Not required for keys created in 0.6.2+.")
    partial_failure_response_code: Optional[StrictInt] = Field(default=None, description="Ordinarily, if a batch item fails to decrypt due to a bad input, but other batch items succeed, the HTTP response code is 400 (Bad Request). Some applications may want to treat partial failures differently. Providing the parameter returns the given response code integer instead of a 400 in this case. If all values fail HTTP 400 is still returned.")
    __properties: ClassVar[List[str]] = ["associated_data", "batch_input", "ciphertext", "context", "nonce", "partial_failure_response_code"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TransitDecryptRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TransitDecryptRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "associated_data": obj.get("associated_data"),
            "batch_input": obj.get("batch_input"),
            "ciphertext": obj.get("ciphertext"),
            "context": obj.get("context"),
            "nonce": obj.get("nonce"),
            "partial_failure_response_code": obj.get("partial_failure_response_code")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_read_issuer_response import PkiReadIssuerResponse

class TestPkiReadIssuerResponse(unittest.TestCase):
    """PkiReadIssuerResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiReadIssuerResponse:
        """Test PkiReadIssuerResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiReadIssuerResponse`
        """
        model = PkiReadIssuerResponse()
        if include_optional:
            return PkiReadIssuerResponse(
                ca_chain = [
                    ''
                    ],
                certificate = '',
                crl_distribution_points = [
                    ''
                    ],
                enable_aia_url_templating = True,
                issuer_id = '',
                issuer_name = '',
                issuing_certificates = [
                    ''
                    ],
                key_id = '',
                leaf_not_after_behavior = '',
                manual_chain = [
                    ''
                    ],
                ocsp_servers = [
                    ''
                    ],
                revocation_signature_algorithm = '',
                revocation_time = 56,
                revocation_time_rfc3339 = '',
                revoked = True,
                usage = ''
            )
        else:
            return PkiReadIssuerResponse(
        )
        """

    def testPkiReadIssuerResponse(self):
        """Test PkiReadIssuerResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.ssh_write_role_request import SshWriteRoleRequest

class TestSshWriteRoleRequest(unittest.TestCase):
    """SshWriteRoleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SshWriteRoleRequest:
        """Test SshWriteRoleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SshWriteRoleRequest`
        """
        model = SshWriteRoleRequest()
        if include_optional:
            return SshWriteRoleRequest(
                algorithm_signer = '',
                allow_bare_domains = True,
                allow_host_certificates = True,
                allow_subdomains = True,
                allow_user_certificates = True,
                allow_user_key_ids = True,
                allowed_critical_options = '',
                allowed_domains = '',
                allowed_domains_template = True,
                allowed_extensions = '',
                allowed_user_key_lengths = None,
                allowed_users = '',
                allowed_users_template = True,
                cidr_list = '',
                default_critical_options = None,
                default_extensions = None,
                default_extensions_template = True,
                default_user = '',
                default_user_template = True,
                exclude_cidr_list = '',
                key_id_format = '',
                key_type = 'otp',
                max_ttl = '',
                not_before_duration = '30',
                port = 56,
                ttl = ''
            )
        else:
            return SshWriteRoleRequest(
        )
        """

    def testSshWriteRoleRequest(self):
        """Test SshWriteRoleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class AzureWriteAuthRoleRequest(BaseModel):
    """
    AzureWriteAuthRoleRequest
    """ # noqa: E501
    bound_group_ids: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of group ids that login is restricted to.")
    bound_locations: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of locations that login is restricted to.")
    bound_resource_groups: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of resource groups that login is restricted to.")
    bound_scale_sets: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of scale sets that login is restricted to.")
    bound_service_principal_ids: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of service principal ids that login is restricted to.")
    bound_subscription_ids: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of subscription ids that login is restricted to.")
    max_ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_max_ttl\" instead. If this and \"token_max_ttl\" are both specified, only \"token_max_ttl\" will be used.")
    num_uses: Optional[StrictInt] = Field(default=None, description="Use \"token_num_uses\" instead. If this and \"token_num_uses\" are both specified, only \"token_num_uses\" will be used.")
    period: Optional[StrictStr] = Field(default=None, description="Use \"token_period\" instead. If this and \"token_period\" are both specified, only \"token_period\" will be used.")
    policies: Optional[List[StrictStr]] = Field(default=None, description="Use \"token_policies\" instead. If this and \"token_policies\" are both specified, only \"token_policies\" will be used.")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum lifetime of the generated token")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_policies: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of policies")
    token_ttl: Optional[StrictStr] = Field(default=None, description="The initial ttl of the token to generate")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    ttl: Optional[StrictStr] = Field(default=None, description="Use \"token_ttl\" instead. If this and \"token_ttl\" are both specified, only \"token_ttl\" will be used.")
    __properties: ClassVar[List[str]] = ["bound_group_ids", "bound_locations", "bound_resource_groups", "bound_scale_sets", "bound_service_principal_ids", "bound_subscription_ids", "max_ttl", "num_uses", "period", "policies", "token_bound_cidrs", "token_explicit_max_ttl", "token_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_policies", "token_ttl", "token_type", "ttl"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AzureWriteAuthRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AzureWriteAuthRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "bound_group_ids": obj.get("bound_group_ids"),
            "bound_locations": obj.get("bound_locations"),
            "bound_resource_groups": obj.get("bound_resource_groups"),
            "bound_scale_sets": obj.get("bound_scale_sets"),
            "bound_service_principal_ids": obj.get("bound_service_principal_ids"),
            "bound_subscription_ids": obj.get("bound_subscription_ids"),
            "max_ttl": obj.get("max_ttl"),
            "num_uses": obj.get("num_uses"),
            "period": obj.get("period"),
            "policies": obj.get("policies"),
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_max_ttl": obj.get("token_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_policies": obj.get("token_policies"),
            "token_ttl": obj.get("token_ttl"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service',
            "ttl": obj.get("ttl")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class TokenWriteRoleRequest(BaseModel):
    """
    TokenWriteRoleRequest
    """ # noqa: E501
    allowed_entity_aliases: Optional[List[StrictStr]] = Field(default=None, description="String or JSON list of allowed entity aliases. If set, specifies the entity aliases which are allowed to be used during token generation. This field supports globbing.")
    allowed_policies: Optional[List[StrictStr]] = Field(default=None, description="If set, tokens can be created with any subset of the policies in this list, rather than the normal semantics of tokens being a subset of the calling token's policies. The parameter is a comma-delimited string of policy names.")
    allowed_policies_glob: Optional[List[StrictStr]] = Field(default=None, description="If set, tokens can be created with any subset of glob matched policies in this list, rather than the normal semantics of tokens being a subset of the calling token's policies. The parameter is a comma-delimited string of policy name globs.")
    bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Use 'token_bound_cidrs' instead.")
    disallowed_policies: Optional[List[StrictStr]] = Field(default=None, description="If set, successful token creation via this role will require that no policies in the given list are requested. The parameter is a comma-delimited string of policy names.")
    disallowed_policies_glob: Optional[List[StrictStr]] = Field(default=None, description="If set, successful token creation via this role will require that no requested policies glob match any of policies in this list. The parameter is a comma-delimited string of policy name globs.")
    explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="Use 'token_explicit_max_ttl' instead.")
    orphan: Optional[StrictBool] = Field(default=None, description="If true, tokens created via this role will be orphan tokens (have no parent)")
    path_suffix: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will contain the given suffix as a part of their path. This can be used to assist use of the 'revoke-prefix' endpoint later on. The given suffix must match the regular expression.\\w[\\w-.]+\\w")
    period: Optional[StrictStr] = Field(default=None, description="Use 'token_period' instead.")
    renewable: Optional[StrictBool] = Field(default=True, description="Tokens created via this role will be renewable or not according to this value. Defaults to \"true\".")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    __properties: ClassVar[List[str]] = ["allowed_entity_aliases", "allowed_policies", "allowed_policies_glob", "bound_cidrs", "disallowed_policies", "disallowed_policies_glob", "explicit_max_ttl", "orphan", "path_suffix", "period", "renewable", "token_bound_cidrs", "token_explicit_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TokenWriteRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TokenWriteRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowed_entity_aliases": obj.get("allowed_entity_aliases"),
            "allowed_policies": obj.get("allowed_policies"),
            "allowed_policies_glob": obj.get("allowed_policies_glob"),
            "bound_cidrs": obj.get("bound_cidrs"),
            "disallowed_policies": obj.get("disallowed_policies"),
            "disallowed_policies_glob": obj.get("disallowed_policies_glob"),
            "explicit_max_ttl": obj.get("explicit_max_ttl"),
            "orphan": obj.get("orphan"),
            "path_suffix": obj.get("path_suffix"),
            "period": obj.get("period"),
            "renewable": obj.get("renewable") if obj.get("renewable") is not None else True,
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service'
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.generate_random_with_source_request import GenerateRandomWithSourceRequest

class TestGenerateRandomWithSourceRequest(unittest.TestCase):
    """GenerateRandomWithSourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GenerateRandomWithSourceRequest:
        """Test GenerateRandomWithSourceRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GenerateRandomWithSourceRequest`
        """
        model = GenerateRandomWithSourceRequest()
        if include_optional:
            return GenerateRandomWithSourceRequest(
                bytes = 56,
                format = 'base64'
            )
        else:
            return GenerateRandomWithSourceRequest(
        )
        """

    def testGenerateRandomWithSourceRequest(self):
        """Test GenerateRandomWithSourceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.auth_read_configuration_response import AuthReadConfigurationResponse

class TestAuthReadConfigurationResponse(unittest.TestCase):
    """AuthReadConfigurationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthReadConfigurationResponse:
        """Test AuthReadConfigurationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthReadConfigurationResponse`
        """
        model = AuthReadConfigurationResponse()
        if include_optional:
            return AuthReadConfigurationResponse(
                accessor = '',
                config = None,
                deprecation_status = '',
                description = '',
                external_entropy_access = True,
                local = True,
                options = None,
                plugin_version = '',
                running_plugin_version = '',
                running_sha256 = '',
                seal_wrap = True,
                type = '',
                uuid = ''
            )
        else:
            return AuthReadConfigurationResponse(
        )
        """

    def testAuthReadConfigurationResponse(self):
        """Test AuthReadConfigurationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.jwt_oidc_callback_form_post_request import JwtOidcCallbackFormPostRequest

class TestJwtOidcCallbackFormPostRequest(unittest.TestCase):
    """JwtOidcCallbackFormPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JwtOidcCallbackFormPostRequest:
        """Test JwtOidcCallbackFormPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JwtOidcCallbackFormPostRequest`
        """
        model = JwtOidcCallbackFormPostRequest()
        if include_optional:
            return JwtOidcCallbackFormPostRequest(
                client_nonce = '',
                code = '',
                id_token = '',
                state = ''
            )
        else:
            return JwtOidcCallbackFormPostRequest(
        )
        """

    def testJwtOidcCallbackFormPostRequest(self):
        """Test JwtOidcCallbackFormPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MountsEnableSecretsEngineRequest(BaseModel):
    """
    MountsEnableSecretsEngineRequest
    """ # noqa: E501
    config: Optional[Dict[str, Any]] = Field(default=None, description="Configuration for this mount, such as default_lease_ttl and max_lease_ttl.")
    description: Optional[StrictStr] = Field(default=None, description="User-friendly description for this mount.")
    external_entropy_access: Optional[StrictBool] = Field(default=False, description="Whether to give the mount access to Vault's external entropy.")
    local: Optional[StrictBool] = Field(default=False, description="Mark the mount as a local mount, which is not replicated and is unaffected by replication.")
    options: Optional[Dict[str, Any]] = Field(default=None, description="The options to pass into the backend. Should be a json object with string keys and values.")
    plugin_name: Optional[StrictStr] = Field(default=None, description="Name of the plugin to mount based from the name registered in the plugin catalog.")
    plugin_version: Optional[StrictStr] = Field(default=None, description="The semantic version of the plugin to use, or image tag if oci_image is provided.")
    seal_wrap: Optional[StrictBool] = Field(default=False, description="Whether to turn on seal wrapping for the mount.")
    type: Optional[StrictStr] = Field(default=None, description="The type of the backend. Example: \"passthrough\"")
    __properties: ClassVar[List[str]] = ["config", "description", "external_entropy_access", "local", "options", "plugin_name", "plugin_version", "seal_wrap", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MountsEnableSecretsEngineRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MountsEnableSecretsEngineRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "config": obj.get("config"),
            "description": obj.get("description"),
            "external_entropy_access": obj.get("external_entropy_access") if obj.get("external_entropy_access") is not None else False,
            "local": obj.get("local") if obj.get("local") is not None else False,
            "options": obj.get("options"),
            "plugin_name": obj.get("plugin_name"),
            "plugin_version": obj.get("plugin_version"),
            "seal_wrap": obj.get("seal_wrap") if obj.get("seal_wrap") is not None else False,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class KerberosConfigureLdapRequest(BaseModel):
    """
    KerberosConfigureLdapRequest
    """ # noqa: E501
    anonymous_group_search: Optional[StrictBool] = Field(default=False, description="Use anonymous binds when performing LDAP group searches (if true the initial credentials will still be used for the initial connection test).")
    binddn: Optional[StrictStr] = Field(default=None, description="LDAP DN for searching for the user DN (optional)")
    bindpass: Optional[StrictStr] = Field(default=None, description="LDAP password for searching for the user DN (optional)")
    case_sensitive_names: Optional[StrictBool] = Field(default=None, description="If true, case sensitivity will be used when comparing usernames and groups for matching policies.")
    certificate: Optional[StrictStr] = Field(default=None, description="CA certificate to use when verifying LDAP server certificate, must be x509 PEM encoded (optional)")
    client_tls_cert: Optional[StrictStr] = Field(default=None, description="Client certificate to provide to the LDAP server, must be x509 PEM encoded (optional)")
    client_tls_key: Optional[StrictStr] = Field(default=None, description="Client certificate key to provide to the LDAP server, must be x509 PEM encoded (optional)")
    connection_timeout: Optional[StrictStr] = Field(default='30s', description="Timeout, in seconds, when attempting to connect to the LDAP server before trying the next URL in the configuration.")
    deny_null_bind: Optional[StrictBool] = Field(default=True, description="Denies an unauthenticated LDAP bind request if the user's password is empty; defaults to true")
    dereference_aliases: Optional[StrictStr] = Field(default='never', description="When aliases should be dereferenced on search operations. Accepted values are 'never', 'finding', 'searching', 'always'. Defaults to 'never'.")
    discoverdn: Optional[StrictBool] = Field(default=None, description="Use anonymous bind to discover the bind DN of a user (optional)")
    groupattr: Optional[StrictStr] = Field(default='cn', description="LDAP attribute to follow on objects returned by <groupfilter> in order to enumerate user group membership. Examples: \"cn\" or \"memberOf\", etc. Default: cn")
    groupdn: Optional[StrictStr] = Field(default=None, description="LDAP search base to use for group membership search (eg: ou=Groups,dc=example,dc=org)")
    groupfilter: Optional[StrictStr] = Field(default='(|(memberUid={{.Username}})(member={{.UserDN}})(uniqueMember={{.UserDN}}))', description="Go template for querying group membership of user (optional) The template can access the following context variables: UserDN, Username Example: (&(objectClass=group)(member:1.2.840.113556.1.4.1941:={{.UserDN}})) Default: (|(memberUid={{.Username}})(member={{.UserDN}})(uniqueMember={{.UserDN}}))")
    insecure_tls: Optional[StrictBool] = Field(default=None, description="Skip LDAP server SSL Certificate verification - VERY insecure (optional)")
    max_page_size: Optional[StrictInt] = Field(default=0, description="If set to a value greater than 0, the LDAP backend will use the LDAP server's paged search control to request pages of up to the given size. This can be used to avoid hitting the LDAP server's maximum result size limit. Otherwise, the LDAP backend will not use the paged search control.")
    request_timeout: Optional[StrictStr] = Field(default='90s', description="Timeout, in seconds, for the connection when making requests against the server before returning back an error.")
    starttls: Optional[StrictBool] = Field(default=None, description="Issue a StartTLS command after establishing unencrypted connection (optional)")
    tls_max_version: Optional[StrictStr] = Field(default='tls12', description="Maximum TLS version to use. Accepted values are 'tls10', 'tls11', 'tls12' or 'tls13'. Defaults to 'tls12'")
    tls_min_version: Optional[StrictStr] = Field(default='tls12', description="Minimum TLS version to use. Accepted values are 'tls10', 'tls11', 'tls12' or 'tls13'. Defaults to 'tls12'")
    token_bound_cidrs: Optional[List[StrictStr]] = Field(default=None, description="Comma separated string or JSON list of CIDR blocks. If set, specifies the blocks of IP addresses which are allowed to use the generated token.")
    token_explicit_max_ttl: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role carry an explicit maximum TTL. During renewal, the current maximum TTL values of the role and the mount are not checked for changes, and any updates to these values will have no effect on the token being renewed.")
    token_max_ttl: Optional[StrictStr] = Field(default=None, description="The maximum lifetime of the generated token")
    token_no_default_policy: Optional[StrictBool] = Field(default=None, description="If true, the 'default' policy will not automatically be added to generated tokens")
    token_num_uses: Optional[StrictInt] = Field(default=None, description="The maximum number of times a token may be used, a value of zero means unlimited")
    token_period: Optional[StrictStr] = Field(default=None, description="If set, tokens created via this role will have no max lifetime; instead, their renewal period will be fixed to this value. This takes an integer number of seconds, or a string duration (e.g. \"24h\").")
    token_policies: Optional[List[StrictStr]] = Field(default=None, description="Comma-separated list of policies. This will apply to all tokens generated by this auth method, in addition to any configured for specific users/groups.")
    token_ttl: Optional[StrictStr] = Field(default=None, description="The initial ttl of the token to generate")
    token_type: Optional[StrictStr] = Field(default='default-service', description="The type of token to generate, service or batch")
    upndomain: Optional[StrictStr] = Field(default=None, description="Enables userPrincipalDomain login with [username]@UPNDomain (optional)")
    url: Optional[StrictStr] = Field(default='ldap://127.0.0.1', description="LDAP URL to connect to (default: ldap://127.0.0.1). Multiple URLs can be specified by concatenating them with commas; they will be tried in-order.")
    use_pre111_group_cn_behavior: Optional[StrictBool] = Field(default=None, description="In Vault 1.1.1 a fix for handling group CN values of different cases unfortunately introduced a regression that could cause previously defined groups to not be found due to a change in the resulting name. If set true, the pre-1.1.1 behavior for matching group CNs will be used. This is only needed in some upgrade scenarios for backwards compatibility. It is enabled by default if the config is upgraded but disabled by default on new configurations.")
    use_token_groups: Optional[StrictBool] = Field(default=False, description="If true, use the Active Directory tokenGroups constructed attribute of the user to find the group memberships. This will find all security groups including nested ones.")
    userattr: Optional[StrictStr] = Field(default='cn', description="Attribute used for users (default: cn)")
    userdn: Optional[StrictStr] = Field(default=None, description="LDAP domain to use for users (eg: ou=People,dc=example,dc=org)")
    userfilter: Optional[StrictStr] = Field(default='({{.UserAttr}}={{.Username}})', description="Go template for LDAP user search filer (optional) The template can access the following context variables: UserAttr, Username Default: ({{.UserAttr}}={{.Username}})")
    username_as_alias: Optional[StrictBool] = Field(default=False, description="If true, sets the alias name to the username")
    __properties: ClassVar[List[str]] = ["anonymous_group_search", "binddn", "bindpass", "case_sensitive_names", "certificate", "client_tls_cert", "client_tls_key", "connection_timeout", "deny_null_bind", "dereference_aliases", "discoverdn", "groupattr", "groupdn", "groupfilter", "insecure_tls", "max_page_size", "request_timeout", "starttls", "tls_max_version", "tls_min_version", "token_bound_cidrs", "token_explicit_max_ttl", "token_max_ttl", "token_no_default_policy", "token_num_uses", "token_period", "token_policies", "token_ttl", "token_type", "upndomain", "url", "use_pre111_group_cn_behavior", "use_token_groups", "userattr", "userdn", "userfilter", "username_as_alias"]

    @field_validator('dereference_aliases')
    def dereference_aliases_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['never', 'finding', 'searching', 'always']):
            raise ValueError("must be one of enum values ('never', 'finding', 'searching', 'always')")
        return value

    @field_validator('tls_max_version')
    def tls_max_version_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['tls10', 'tls11', 'tls12', 'tls13']):
            raise ValueError("must be one of enum values ('tls10', 'tls11', 'tls12', 'tls13')")
        return value

    @field_validator('tls_min_version')
    def tls_min_version_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['tls10', 'tls11', 'tls12', 'tls13']):
            raise ValueError("must be one of enum values ('tls10', 'tls11', 'tls12', 'tls13')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of KerberosConfigureLdapRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of KerberosConfigureLdapRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "anonymous_group_search": obj.get("anonymous_group_search") if obj.get("anonymous_group_search") is not None else False,
            "binddn": obj.get("binddn"),
            "bindpass": obj.get("bindpass"),
            "case_sensitive_names": obj.get("case_sensitive_names"),
            "certificate": obj.get("certificate"),
            "client_tls_cert": obj.get("client_tls_cert"),
            "client_tls_key": obj.get("client_tls_key"),
            "connection_timeout": obj.get("connection_timeout") if obj.get("connection_timeout") is not None else '30s',
            "deny_null_bind": obj.get("deny_null_bind") if obj.get("deny_null_bind") is not None else True,
            "dereference_aliases": obj.get("dereference_aliases") if obj.get("dereference_aliases") is not None else 'never',
            "discoverdn": obj.get("discoverdn"),
            "groupattr": obj.get("groupattr") if obj.get("groupattr") is not None else 'cn',
            "groupdn": obj.get("groupdn"),
            "groupfilter": obj.get("groupfilter") if obj.get("groupfilter") is not None else '(|(memberUid={{.Username}})(member={{.UserDN}})(uniqueMember={{.UserDN}}))',
            "insecure_tls": obj.get("insecure_tls"),
            "max_page_size": obj.get("max_page_size") if obj.get("max_page_size") is not None else 0,
            "request_timeout": obj.get("request_timeout") if obj.get("request_timeout") is not None else '90s',
            "starttls": obj.get("starttls"),
            "tls_max_version": obj.get("tls_max_version") if obj.get("tls_max_version") is not None else 'tls12',
            "tls_min_version": obj.get("tls_min_version") if obj.get("tls_min_version") is not None else 'tls12',
            "token_bound_cidrs": obj.get("token_bound_cidrs"),
            "token_explicit_max_ttl": obj.get("token_explicit_max_ttl"),
            "token_max_ttl": obj.get("token_max_ttl"),
            "token_no_default_policy": obj.get("token_no_default_policy"),
            "token_num_uses": obj.get("token_num_uses"),
            "token_period": obj.get("token_period"),
            "token_policies": obj.get("token_policies"),
            "token_ttl": obj.get("token_ttl"),
            "token_type": obj.get("token_type") if obj.get("token_type") is not None else 'default-service',
            "upndomain": obj.get("upndomain"),
            "url": obj.get("url") if obj.get("url") is not None else 'ldap://127.0.0.1',
            "use_pre111_group_cn_behavior": obj.get("use_pre111_group_cn_behavior"),
            "use_token_groups": obj.get("use_token_groups") if obj.get("use_token_groups") is not None else False,
            "userattr": obj.get("userattr") if obj.get("userattr") is not None else 'cn',
            "userdn": obj.get("userdn"),
            "userfilter": obj.get("userfilter") if obj.get("userfilter") is not None else '({{.UserAttr}}={{.Username}})',
            "username_as_alias": obj.get("username_as_alias") if obj.get("username_as_alias") is not None else False
        })
        return _obj


